@@ -291,7 +291,4 @@ silvamod138 = CrestDatabase('silvamod138',
                             'Silva version 138 modified for CREST')
 
 silvamod128 = CrestDatabase('silvamod128',
-                            'Silva version 128 modified for CREST')
-
-bold        = CrestDatabase('bold',
-                            'The BOLD database modified for CREST')
\ No newline at end of file
+                            'Silva version 128 modified for CREST')
\ No newline at end of file
